Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'source/blender/makesrna/RNA_types.h')
-rw-r--r--source/blender/makesrna/RNA_types.h8
1 files changed, 3 insertions, 5 deletions
diff --git a/source/blender/makesrna/RNA_types.h b/source/blender/makesrna/RNA_types.h
index 38631d1acf2..2a341249247 100644
--- a/source/blender/makesrna/RNA_types.h
+++ b/source/blender/makesrna/RNA_types.h
@@ -29,6 +29,7 @@ extern "C" {
struct BlenderRNA;
struct FunctionRNA;
+struct ID;
struct Main;
struct ParameterList;
struct PropertyRNA;
@@ -44,10 +45,7 @@ struct bContext;
* the properties and validate them. */
typedef struct PointerRNA {
- struct {
- void *data;
- } id;
-
+ struct ID *owner_id;
struct StructRNA *type;
void *data;
} PointerRNA;
@@ -534,7 +532,7 @@ typedef struct ParameterDynAlloc {
typedef enum FunctionFlag {
/**
* Pass ID owning 'self' data
* (i.e. ptr->id.data, might be same as self in case data is an ID...).
*/
FUNC_USE_SELF_ID = (1 << 11),
@@ -534,7 +532,7 @@ typedef struct ParameterDynAlloc {
/**
* Pass ID owning 'self' data
- * (i.e. ptr->id.data, might be same as self in case data is an ID...).
+ * (i.e. ptr->owner_id, might be same as self in case data is an ID...).
*/
FUNC_USE_SELF_ID = (1 << 11),